require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe
module UU

  # Module Finman
  module Finman

    # Module of finman Financial transaction
    module FinancialTransaction

      # DTO for setAttributes command of Credit note.
      class CreditNoteSetAttributes< UU::OS::REST::DTO

        # Name of Financial Transaction. Cannot be empty.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Amount of the Financial Transaction without vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_without_vat

        # Amount of the Financial Transaction with vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_with_vat

        # Constant symbol.
        # @param [String]
        # @return [String]
        attr_accessor :constant_symbol

        # UESURI of Contract.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :contract_uri

        # Code of cost item.
        # @param [String]
        # @return [String]
        attr_accessor :cost_item_code

        # Number of supplier account.
        # @param [String]
        # @return [String]
        attr_accessor :supplier_account_number

        # UESURI of supplier account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :supplier_account_uri

        # Description for supplier side.
        # @param [String]
        # @return [String]
        attr_accessor :supplier_description

        # UESURI of supplier financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :supplier_financial_category_uri

        # Supplier vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :supplier_vat_date

        # Number of client account.
        # @param [String]
        # @return [String]
        attr_accessor :client_account_number

        # UESURI of client account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :client_account_uri

        # Description for client side.
        # @param [String]
        # @return [String]
        attr_accessor :client_description

        # UESURI of client financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :client_financial_category_uri

        # Client vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :client_vat_date

        # Date the payment is due to be paid.
        # @param [String, Time]
        # @return [String]
        attr_accessor :due_date

        # Date the payment is expected to be payed to.
        # @param [String, Time]
        # @return [String]
        attr_accessor :expected_pay_date

        # Type of financial transaction. CASH or NONCASH.
        # @param [FinancialTransactionType]
        # @return [FinancialTransactionType]
        attr_accessor :financial_transaction_type

        # Code of income item.
        # @param [String]
        # @return [String]
        attr_accessor :income_item_code

        # Invoice number of financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :invoice_number

        # Date of invoicing to the counterparty.
        # @param [String, Time]
        # @return [String]
        attr_accessor :protocol_date

        # Probability of payment realization in %.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :realization_probability

        # Specific symbol.
        # @param [String]
        # @return [String]
        attr_accessor :specific_symbol

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Vat rate.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :vat_rate

        # Possible values: true or false. Specifies whether it is needed to confirm the acceptance of the credit
        # note by client's accountant.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :wait_for_acceptance_by_accountant

        # Explicit exchange rate. Can be set only by role cast in Accounting Authorities.
        # Set to 0 to unset explicit exchange rate.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :explicit_exchange_rate

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end

        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end

        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end

        def contract_uri
          attributes[:contractUri]
        end

        def contract_uri=(val)
          if val
            attributes[:contractUri] = UU::OS::UESURI.new(val)
          else
            attributes[:contractUri] = nil
          end
        end

        def cost_item_code
          attributes[:costItemCode]
        end

        def cost_item_code=(val)
          attributes[:costItemCode] = val
        end

        def supplier_account_number
          attributes[:supplierAccountNumber]
        end

        def supplier_account_number=(val)
          attributes[:supplierAccountNumber] = val
        end

        def supplier_account_uri
          attributes[:supplierAccountUri]
        end

        def supplier_account_uri=(val)
          if val
            attributes[:supplierAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:supplierAccountUri] = nil
          end
        end

        def supplier_description
          attributes[:supplierDescription]
        end

        def supplier_description=(val)
          attributes[:supplierDescription] = val
        end

        def supplier_financial_category_uri
          attributes[:supplierFinancialCategoryUri]
        end

        def supplier_financial_category_uri=(val)
          if val
            attributes[:supplierFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:supplierFinancialCategoryUri] = nil
          end
        end

        def supplier_vat_date
          attributes[:supplierVatDate]
        end

        def supplier_vat_date=(val)
          attributes[:supplierVatDate] = val
        end

        def client_account_number
          attributes[:clientAccountNumber]
        end

        def client_account_number=(val)
          attributes[:clientAccountNumber] = val
        end

        def client_account_uri
          attributes[:clientAccountUri]
        end

        def client_account_uri=(val)
          if val
            attributes[:clientAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:clientAccountUri] = nil
          end
        end

        def client_description
          attributes[:clientDescription]
        end

        def client_description=(val)
          attributes[:clientDescription] = val
        end

        def client_financial_category_uri
          attributes[:clientFinancialCategoryUri]
        end

        def client_financial_category_uri=(val)
          if val
            attributes[:clientFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:clientFinancialCategoryUri] = nil
          end
        end

        def client_vat_date
          attributes[:clientVatDate]
        end

        def client_vat_date=(val)
          attributes[:clientVatDate] = val
        end

        def due_date
          attributes[:dueDate]
        end

        def due_date=(val)
          attributes[:dueDate] = val
        end

        def expected_pay_date
          attributes[:expectedPayDate]
        end

        def expected_pay_date=(val)
          attributes[:expectedPayDate] = val
        end

        def financial_transaction_type
          attributes[:financialTransactionType]
        end

        def financial_transaction_type=(val)
          attributes[:financialTransactionType] = val
        end

        def income_item_code
          attributes[:incomeItemCode]
        end

        def income_item_code=(val)
          attributes[:incomeItemCode] = val
        end

        def invoice_number
          attributes[:invoiceNumber]
        end

        def invoice_number=(val)
          attributes[:invoiceNumber] = val
        end

        def original_amount_with_vat
          attributes[:originalAmountWithVat]
        end

        def protocol_date
          attributes[:protocolDate]
        end

        def protocol_date=(val)
          attributes[:protocolDate] = val
        end

        def realization_probability
          attributes[:realizationProbability]
        end

        def realization_probability=(val)
          attributes[:realizationProbability] = val
        end

        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end

        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end

        def vat_rate
          attributes[:vatRate]
        end

        def vat_rate=(val)
          attributes[:vatRate] = val
        end

        def wait_for_acceptance_by_accountant
          attributes[:waitForAcceptanceByAccountant]
        end

        def wait_for_acceptance_by_accountant=(val)
          attributes[:waitForAcceptanceByAccountant] = val
        end

        def explicit_exchange_rate
          attributes[:explicitExchangeRate]
        end

        def explicit_exchange_rate=(val)
          attributes[:explicitExchangeRate] = val
        end

      end
    end
  end
end

